@@ -184,6 +184,6 @@ test_that("Fits in validity vignette", {
   med_dec <- med_dec[which(med_dec[["rt"]] >= 0),]
   newfit <- rt_fit(med_dec, id_idx = c(2,1), rt_idx = 8, response_idx = 7,
                    truth_idx = 5, response_upper = "blast", err_tol = 1e-6)
-  load(system.file("extdata", "valid_fit.Rds", package = "fddm", mustWork = TRUE))
+  load(system.file("extdata", "dfddm_density", "valid_fit.Rds", package = "fddm", mustWork = TRUE))
   expect_equal(newfit[["Objective"]], fit[["Objective"]], tolerance = 0.01)
 })
